@@ -444,6 +444,18 @@ class TestVersions(base.BaseTestCase):
         version = packaging._get_version_from_git()
         self.assertEqual('1.3.0.0a1', version)
 
+    def test_skip_write_git_changelog(self):
+        # Fix for bug 1467440
+        self.repo.commit()
+        self.repo.tag('1.2.3')
+        os.environ['SKIP_WRITE_GIT_CHANGELOG'] = '1'
+        version = packaging._get_version_from_git('1.2.3')
+        self.assertEqual('1.2.3', version)
+
+    def tearDown(self):
+        super(TestVersions, self).tearDown()
+        os.environ.pop('SKIP_WRITE_GIT_CHANGELOG', None)
+
 
 class TestRequirementParsing(base.BaseTestCase):
 
@@ -454,6 +466,9 @@ class TestRequirementParsing(base.BaseTestCase):
             f.write(textwrap.dedent(six.u("""\
                 bar
                 quux<1.0; python_version=='2.6'
+                requests-aws>=0.1.4    # BSD License (3 clause)
+                Routes>=1.12.3,!=2.0,!=2.1;python_version=='2.7'
+                requests-kerberos>=0.6;python_version=='2.7' # MIT
             """)))
         setup_cfg = os.path.join(tempdir, 'setup.cfg')
         with open(setup_cfg, 'wt') as f:
@@ -469,11 +484,14 @@ class TestRequirementParsing(base.BaseTestCase):
         # pkg_resources.split_sections uses None as the title of an
         # anonymous section instead of the empty string. Weird.
         expected_requirements = {
-            None: ['bar'],
+            None: ['bar', 'requests-aws>=0.1.4'],
             ":(python_version=='2.6')": ['quux<1.0'],
-            "test:(python_version=='2.7')": ['baz>3.2'],
-            "test": ['foo']
+            ":(python_version=='2.7')": ['Routes>=1.12.3,!=2.0,!=2.1',
+                                         'requests-kerberos>=0.6'],
+            'test': ['foo'],
+            "test:(python_version=='2.7')": ['baz>3.2']
         }
+
         setup_py = os.path.join(tempdir, 'setup.py')
         with open(setup_py, 'wt') as f:
             f.write(textwrap.dedent(six.u("""\
